@@ -13,6 +13,7 @@
 #include "kwebenginepartlib_export.h"
 
 #include "browserextension.h"
+#include "actondownloadedfilebar.h"
 
 #include <QWebEnginePage>
 
@@ -20,6 +21,9 @@
 #include <KParts/ReadOnlyPart>
 #include <QUrl>
 #include <QWebEngineScript>
+#include <QPointer>
+
+#include <KMessageWidget>
 
 namespace KParts {
 //TODO KF6: when removing compatibility with KF5, uncomment the line below
@@ -41,6 +45,14 @@ class KPluginMetaData;
 class WebEnginePartControls;
 class WebEngineDownloaderExtension;
 
+namespace KonqInterfaces {
+    class DownloaderJob;
+}
+
+namespace WebEngine {
+    class ActOnDownloadedFileBar;
+}
+
 /**
  * A KPart wrapper for the QtWebEngine's browser rendering engine.
  *
@@ -111,10 +123,6 @@ public:
 
     WebEngineWallet* wallet() const;
 
-#if QT_VERSION_MAJOR < 6
-    KParts::NavigationExtension* navigationExtension() const;
-#endif
-
     /**
      * @brief Changes the page object associated with the part
      *
@@ -143,6 +151,11 @@ public Q_SLOTS:
     void exitFullScreen();
     void setInspectedPart(KParts::ReadOnlyPart *part);
 
+    /**
+     * @brief Displays a widget which the user can use to display or open a file he has just finished downloading
+     */
+    void displayActOnDownloadedFileBar(KonqInterfaces::DownloaderJob *job);
+
 protected:
     /**
      * Re-implemented for internal reasons. API remains unaffected.
@@ -172,7 +185,26 @@ private Q_SLOTS:
     void slotLinkMiddleOrCtrlClicked(const QUrl&);
     void slotSelectionClipboardUrlPasted(const QUrl&, const QString&);
 
-    void slotUrlChanged(const QUrl &);
+    /**
+     * @brief Slot called in response to WebEnginePage::urlChanged signal
+     *
+     * It main task is to call setUrl and emit the setLocationBar signal. However, due to the fact that
+     * WebEnginePage::loadStarted isn't always emitted (in particular, it isn't emitted when the history API
+     * is used, see https://bugreports.qt.io/browse/QTBUG-115589) it will sometimes also call slotLoadStarted.
+     *
+     * @private
+     * In particular, what this does is:
+     * - check whether @p url is the URL for which WebEnignePage::acceptNavigationRequest was called, which
+     *   is stored in #m_lastRequestedUrl
+     * - if the two URLs are equal, it means that the WebEnginePage::loadStarted signal was emitted (it is always emitted
+     *   when WebEngePage::acceptNavigationRequest is called), then it doesn't need to call slotLoadStarted
+     * - if the two URLs are different, it means that WebEnginePage::loadStarted signal was not emitted, so it needs to
+     *   call slotLoadStarted
+     *
+     * @param url the new URL
+     * @see WebEngineNavigationExtension::saveState
+     */
+    void slotUrlChanged(const QUrl &url);
     void resetWallet();
     void slotShowWalletMenu();
     void slotLaunchWalletManager();
@@ -194,6 +226,13 @@ private Q_SLOTS:
     void updateWalletActions();
     void reloadAfterUAChange(const QString &);
 
+    /**
+     * @brief Records the URL for which WebEnginePart::acceptNavigationRequest() was last called
+     * @param page the page which emitted the signal (unused)
+     * @param url the URL for which acceptNavigationRequest was called
+     */
+    void recordNavigationAccepted(WebEnginePage *page, const QUrl &url);
+
 private:
     static void initWebEngineUrlSchemes();
 
@@ -228,6 +267,16 @@ private:
     WebEngineView* m_webView;
     WebEngineWallet* m_wallet;
     WebEngineDownloaderExtension* m_downloader;
+
+    QPointer<WebEngine::ActOnDownloadedFileBar> m_actOnDownloadedFileWidget = nullptr; //!< Widget allowing the user to open a file which was downloaded right now
+
+    /**
+     * @brief The URL for which WebEnginePart::acceptNavigationRequest was last called
+     *
+     * This is used by slotUrlChanged to decide whether it needs to call slotLoadStarted or not
+     */
+    QUrl m_lastRequestedUrl;
 };
 
+
 #endif // WEBENGINEPART_H
